netapp_ontap.models.storage_unit_clone API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.storage_unit_clone`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class StorageUnitCloneSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the StorageUnitClone object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `inherited_physical_used: Size GET`

    Inherited physical used from the clone's base snapshot.

  `inherited_savings: Size GET`

    Inherited savings from the clone's base snapshot.

  `is_flexclone: bool GET POST`

    Specifies if this storage unit is a normal FlexVol storage unit or FlexClone storage unit. Valid in POST.

  `source: StorageUnitCloneSource GET POST PATCH`

    The source field of the storage_unit_clone.

  `split_complete_percent: Size GET`

    Percentage of FlexClone storage unit blocks split from its parent storage unit.

  `split_estimate: Size GET`

    Space required by the containing-aggregate to split the FlexClone storage unit.

  `split_initiated: bool GET POST PATCH`

    This field is set when a split is executed on a FlexClone storage unit, that is when the FlexClone storage unit is split from its parent FlexVol storage unit. Setting this field initiates a split of a FlexClone storage unit from a FlexVol storage unit. Valid in POST and PATCH.